@@ -10,12 +10,12 @@
 #ifdef	MAILER
 #include "sift.h"	/* Include this BEFORE "mailer.h" ! */
 #endif	/* MAILER */
+#include <ctype.h>
+#include <sys/file.h>
+#include <fcntl.h>
 
 #include "mailer.h"
-#include <ctype.h>
-#include <signal.h>
-#include <fcntl.h>
-#include <sys/file.h>
+#include "zmsignal.h"
 
 /* #define static
   #define register */
@@ -29,6 +29,9 @@
 #ifdef	USE_UNIONWAIT
 #include <sys/wait.h>
 #endif	/* USE_UNIONWAIT */
+#ifdef USE_WAITPID
+#include <sys/wait.h>
+#endif
 
 #ifndef	SIGCHLD
 #define	SIGCHLD	SIGCLD
@@ -79,11 +82,11 @@ int smask = DEFAULT_OPEN_MASK;
 					_exit(0);\
 				} else if (P < 0)
 
-#ifdef	WNOHANG
+#ifdef	USE_UNIONWAIT
 typedef union wait status_t;
-#else	/* !WNOHANG */
+#else	/* !USE_UNIONWAIT */
 typedef int status_t;
-#endif	/* WNOHANG */
+#endif	/* !USE_UNIONWAIT */
 
 int reapableTop = 0;			/* top of stack of repable processes */
 STATIC int reapable[MAXNPROC];		/* stack of reapable process ids */
@@ -125,8 +128,8 @@ bgsetup(c)
 {
 	int fd;
 
-	signal(SIGINT, SIG_IGN);		/* ignore interrupt */
-	signal(SIGQUIT, SIG_IGN);	/* ignore quit */
+	SIGNAL_IGNORE(SIGINT);			/* ignore interrupt	*/
+	SIGNAL_IGNORE(SIGQUIT);			/* ignore quit		*/
 	if (!(c->fdmask & 1)) {			/* /dev/null is default input */
 		fd = open("/dev/null", O_RDONLY, 0);
 		if (fd > 0) {
@@ -162,11 +165,11 @@ execute(c, caller, oretcode)
 	SIGNAL_TYPE (*oquit_handler)(), (*oint_handler)(), (*oterm_handler)();
 	SIGNAL_TYPE (*ochld_handler)();
 
-#ifdef	WNOHANG
+#ifdef	USE_UNIONWAIT
 	status.w_status = 0;
-#else	/* !WNOHANG */
+#else	/* !USE_UNIONWAIT */
 	status = 0;
-#endif	/* WNOHANG */
+#endif	/* !USE_UNIONWAIT */
 
 	ochld_handler = SIG_DFL;
 	globalcaller = caller;
@@ -461,15 +464,15 @@ execute(c, caller, oretcode)
 		 * We restore original signal handlers unless if we are
 		 * explicitly ignoring the signal in question.
 		 */
-		oterm_handler = signal(SIGTERM, orig_handler[SIGTERM]);
+		SIGNAL_HANDLESAVE(SIGTERM,orig_handler[SIGTERM],oterm_handler);
 		if (oterm_handler == SIG_IGN && orig_handler[SIGTERM]!=SIG_IGN)
-			signal(SIGTERM, oterm_handler);
-		oint_handler = signal(SIGINT, orig_handler[SIGINT]);
+			SIGNAL_IGNORE(SIGTERM);
+		SIGNAL_HANDLESAVE(SIGINT,orig_handler[SIGINT],oint_handler);
 		if (oint_handler == SIG_IGN && orig_handler[SIGINT] != SIG_IGN)
-			signal(SIGINT, oint_handler);
-		oquit_handler = signal(SIGQUIT, orig_handler[SIGQUIT]);
+			SIGNAL_IGNORE(SIGINT);
+		SIGNAL_HANDLESAVE(SIGQUIT,orig_handler[SIGQUIT],oquit_handler);
 		if (oquit_handler == SIG_IGN && orig_handler[SIGQUIT]!=SIG_IGN)
-			signal(SIGQUIT, oquit_handler);
+			SIGNAL_IGNORE(SIGQUIT);
 		/*
 		 * Go fish
 		 */
@@ -480,9 +483,9 @@ execute(c, caller, oretcode)
 		fprintf(stderr, "%s: %s\n", av[0], NOT_FOUND);
 		if (!nofork)
 			_exit(1);
-		signal(SIGTERM, oterm_handler);
-		signal(SIGINT, oint_handler);
-		signal(SIGQUIT, oquit_handler);
+		SIGNAL_HANDLE(SIGTERM, oterm_handler);
+		SIGNAL_HANDLE(SIGINT, oint_handler);
+		SIGNAL_HANDLE(SIGQUIT, oquit_handler);
 	} else if (pid > 0) {
 		/*
 		 * In the shell, if the child is doing output to a pipe,
@@ -497,7 +500,7 @@ execute(c, caller, oretcode)
 				continue;
 		} else {	/* asynchronous wait */
 			reapable[reapableTop++] = pid;
-			ochld_handler = signal(SIGCHLD, reapchild);
+			SIGNAL_HANDLESAVE(SIGCHLD, reapchild, ochld_handler);
 		}
 	} else {	/* fork failed */
 		retcode = 0200;
@@ -515,7 +518,7 @@ execute(c, caller, oretcode)
 	if (c->undoio) {
 		RUNIO(c->undoio);
 		if (c->iocmd == ioIntoBuffer) {
-			signal(SIGCHLD, ochld_handler);
+			SIGNAL_HANDLE(SIGCHLD, ochld_handler);
 			while (c->reaperTop >= 0 && reapableTop > c->reaperTop)
 				reapchild();
 			/* one way or another it has been reaped */
@@ -559,7 +562,7 @@ execute(c, caller, oretcode)
 			trapexit(retcode);
 		return retcode;
 	}
-#ifdef	WNOHANG
+#ifdef	USE_UNIONWAIT
 	if (status.w_termsig) {
 		if (status.w_termsig != SIGINT) {
 			fprintf(stderr, "%s", sys_siglist[status.w_termsig]);
@@ -570,7 +573,7 @@ execute(c, caller, oretcode)
 		retcode = 0200 + status.w_termsig;
 	} else
 		retcode = status.w_retcode;
-#else	/* !WNOHANG */
+#else	/* !USE_UNIONWAIT */
 	if ((status&0177) > 0) {
 		if ((status&0177) != SIGINT) {
 			fprintf(stderr, "%s", sys_siglist[status&0177]);
@@ -581,7 +584,7 @@ execute(c, caller, oretcode)
 		retcode = 0200 + (status&0177);
 	} else
 		retcode = (status>>8)&0377;
-#endif	/* WNOHANG */
+#endif	/* USE_UNIONWAIT */
 	if (isset('t'))
 		trapexit(retcode);
 	return retcode;
