@@ -1202,8 +1202,8 @@ interpret(code, eocode, entry, caller, retcodep, cdp)
 	command->rval = NULL;
 	variableIndex = -1;
 	variable = NULL;
-	/* ioflags = 0;		*/
-	/* defaultfd = 0;	*/
+	ioflags = 0;
+	defaultfd = 0;
 	dye = 0;
 	dollar = 0;
 	quote = 0;
