@@ -559,9 +559,11 @@ rd_doit(filename, dirs)
 	char *sh_memlevel = getlevel(MEM_SHCMD);
 
 	*pathbuf = 0;
-	if (*dirs)	/* If it is in alternate dir, move to primary one,
+	if (*dirs) {	/* If it is in alternate dir, move to primary one,
 			   and process there! */
 	  strcpy(pathbuf,dirs);
+	  strcat(pathbuf,"/");
+	}
 	strcat(pathbuf,filename);
 
 	if (router_id) {
@@ -1456,7 +1458,7 @@ run_listexpand(avl, il)
 		if (rc != 0 || s_value == NULL || !LIST(s_value)) {
 		  /* $(rrouter xx xx xx)  returned something invalid.. */
 		  s_free_tree(s_value);
-		  s_value == NULL;
+		  s_value = NULL;
 		  continue;
 		} else {
 		  /*
@@ -1464,6 +1466,10 @@ run_listexpand(avl, il)
 		   * (local - user attributes) or (((local - user attributes)))
 		   * or ( ((local - user attr)) ((local - another attr)) )
 		   */
+		  if (car(s_value) == NULL) {
+		    /* duplicate removal trapped it. Empty list! */
+		    continue;
+		  }
 		  if (LIST(car(s_value))) {
 		    if (!LIST(caar(s_value)) || !STRING(caaar(s_value))) {
 		      fprintf(stderr,
