@@ -100,11 +100,17 @@ run_rfc822(argc, argv)
 
 	e = (struct envelope *)tmalloc(sizeof (struct envelope));
 
-	/* open with RDWR permissions so that locks will work */
-	if ((e->e_fp = fopen(file, "r+")) == NULL) {
+	if ((e->e_fp = fopen(file, "r")) == NULL) {
 		fprintf(stderr, "router: cannot open %s\n", file);
 		status = PERR_BADOPEN;
 	} else {
+/* XX: DEBUG STUFF! */
+if (fileno(e->e_fp) < 4) {
+  fprintf(stderr,"RFC822: While opening mail-file '%s', got fd=%d  AARGH! (abort!)",
+	  file, fileno(e->e_fp));
+  fflush(stderr);
+  abort();
+}
 		status = PERR_OK;
 		setvbuf(e->e_fp, buf, _IOFBF, sizeof buf);
 		e->e_file = file;
@@ -1400,7 +1406,7 @@ sequencer(e, file)
 	dprintf("Route recipient addresses\n");
 	routed_addresses = NULL;
 
-	/* if (errors_to) free(errors_to); */
+	if (errors_to) free(errors_to);
 	errors_to = NULL;
 
 	for (h = e->e_eHeaders; h != NULL; h = h->h_next) {
@@ -1483,12 +1489,12 @@ sequencer(e, file)
 			putchar('\n');
 #endif
 			++nxor;
-			tmp = copycell(car(x));
+			tmp   = copycell(car(x));
+			errto = find_errto(cdar(x));
 			cdr(tmp) = NULL;
 			for (rwp = rwhead; rwp != NULL; rwp = rwp->next)
 				if (s_equal(rwp->info, tmp) &&
-				    s_equal(rwp->errto,
-					    (errto = find_errto(cdar(x)))))
+				    s_equal(rwp->errto,errto))
 					break;
 			if (rwp == NULL) {
 				rwp = rwalloc(&rwhead);
@@ -1498,11 +1504,13 @@ sequencer(e, file)
 			tmp = cddar(x);
 			cddar(x) = NULL;
 			for (nsp = rwp->down; nsp != NULL; nsp = nsp->next)
-				if (s_equal(nsp->info, cdar(x)))
+				if (s_equal(nsp->info, cdar(x)) &&
+				    s_equal(nsp->errto,errto))
 					break;
 			if (nsp == NULL) {
 				nsp = rwalloc(&rwp->down);
 				nsp->info = cdar(x);	/* new sender */
+				nsp->errto = errto;
 			}
 #if 0
 			else {
@@ -1517,6 +1525,7 @@ sequencer(e, file)
 			rcp = rwalloc(&nsp->down);
 			rcp->info = tmp;		/* new recipient */
 			rcp->urw.number = idnumber;
+			rcp->errto = NULL;
 #if 0
 			for (rwp = rwhead; rwp != NULL; rwp = rwp->next) {
 				printf("**");
@@ -1610,6 +1619,15 @@ sequencer(e, file)
 	 */
 
 	if (!iserrmessage()) {
+#if 0
+                if (errors_to != NULL) {        /* [mea@utu.fi] Stupid, but workable.. */
+                        putc(_CF_ERRORADDR, ofp);
+                        putc(_CFTAG_NORMAL, ofp);
+                        fprintf(ofp,"%s\n",errors_to);
+                        free(errors_to);
+                        errors_to = NULL;
+                } else
+#endif
 		if ((h = erraddress(e)) != NULL) {
 			putc(_CF_ERRORADDR, ofp);
 			putc(_CFTAG_NORMAL, ofp);
@@ -1624,7 +1642,6 @@ sequencer(e, file)
 			putc('\n', ofp);
 		}
 	}
-
 	/*
 	 * If this message might obsolete another we need to tell
 	 * the scheduler.
@@ -1704,8 +1721,16 @@ sequencer(e, file)
 		vfp = NULL;
 
 	for (rwp = rwhead; rwp != NULL; rwp = rwp->next) {
-		for (nsp = rwp->down; nsp != NULL; nsp = nsp->next) {
+
+		if (!iserrmessage()  &&  rwp->errto != NULL) {
 			/* print envelope sender address */
+                        putc(_CF_ERRORADDR, ofp);
+                        putc(_CFTAG_NORMAL, ofp);
+                        fprintf(ofp,"%s\n",rwp->errto);
+		}
+
+		for (nsp = rwp->down; nsp != NULL; nsp = nsp->next) {
+
 			fprintf(ofp, "%c%c", _CF_SENDER, _CFTAG_NORMAL);
 			prctladdr(nsp->info, ofp, _CF_SENDER, "sender");
 			putc('\n', ofp);
