@@ -563,6 +563,25 @@ pureAddress(fp, pp)
 	}
 }
 
+int
+pureAddressBuf(buf, len, pp)
+	char *buf;
+	int len;
+	register struct addr *pp;
+{
+	register struct token *t;
+	int tlen;
+
+	for (; pp != NULL ; pp = pp->p_next) {
+		if (pp->p_type != anAddress)
+			continue;
+		tlen = printToken(buf, buf+len, pp->p_tokens, NULL, 0);
+		buf += tlen;
+		len -= tlen;
+	}
+	return len;
+}
+
 /*
  * Print the address pointed to by pp onto fp. If the onlylength flag
  * is set, no printing is done, but the number of characters that would
