@@ -26,9 +26,11 @@ extern int loginit();/* should be SIGNAL_TYPE but we're playing games */
 extern int nobody;
 extern int sh_include();
 extern int zshtoplevel();
+
 extern struct group *getgrnam();
 extern struct passwd *getpwnam();
 extern struct passwd *getpwuid();
+
 extern struct shCmd fnctns[];
 extern time_t time();
 extern void getnobody(), prversion();
@@ -85,6 +87,8 @@ main(argc, argv)
 	errflg = daemonflg = killflg = interactiveflg = version = 0;
 	tac = 0;
 	nrouters = 1;
+
+
 	while ((c = getopt(argc, argv, "m:n:dikf:o:t:L:P:V")) != EOF)
 		switch (c) {
 		case 'd':	/* become a daemon */
@@ -600,3 +604,29 @@ mail_host()
 {
 	return myhostname;
 }
+
+void
+printfds()
+{
+	int i, topfd = getdtablesize();
+	struct stat fst;
+
+	for (i=0; i < topfd; ++i) {
+	  long flags = fcntl(i,F_GETFL,0);
+	  if (flags >= 0) {
+	    fstat(i,&fst);
+	    if (S_ISREG(fst.st_mode))
+	      fprintf(stderr," %d",i);
+	    else if (S_ISDIR(fst.st_mode))
+	      fprintf(stderr," %dd",i);
+	    else if (S_ISCHR(fst.st_mode))
+	      fprintf(stderr," %dC",i);
+	    else if (S_ISBLK(fst.st_mode))
+	      fprintf(stderr," %dB",i);
+	    else
+	      fprintf(stderr," %d(?)",i);
+	  }
+	}
+	fprintf(stderr,"\n");
+	fflush(stderr);
+}
