@@ -301,7 +301,7 @@ main(argc, argv)
 	myhostname[0] = '\0';
 	remotemsg[0] = '\0';
 	remotehost[0] = '\0';
-	while ((c = getopt(argc, argv, "c:deh:l:rsxDE:T:VW78")) != EOF) {
+	while ((c = getopt(argc, argv, "c:deh:l:rsxDET:VW78")) != EOF) {
 	  switch (c) {
 	  case 'c':		/* specify channel scanned for */
 	    channel = emalloc(strlen(optarg)+1);
@@ -536,9 +536,8 @@ deliver(dp, smtpfp, verboselog, startrp, endrp)
 	char *s;
 	int conv_prohibit = check_conv_prohibit(startrp);
 
-	if (conv_prohibit < 0) {
-	  convertmode = _CONVERT_NONE;
-	} else {
+	convertmode = _CONVERT_NONE;
+	if (conv_prohibit >= 0) {
 
 	  /* Content-Transfer-Encoding: 8BIT ? */
 	  content_kind = cte_check(startrp);
@@ -557,7 +556,6 @@ deliver(dp, smtpfp, verboselog, startrp, endrp)
 	  if (force_7bit)	/* Mark off the 8BIT MIME capability.. */
 	    ehlo_capabilities &= ~ESMTP_8BITMIME;
 
-	  convertmode = _CONVERT_NONE;
 	  switch (content_kind) {
 	  case 0:		/* Not MIME */
 	    if ((ehlo_capabilities & ESMTP_8BITMIME) == 0 &&
@@ -777,7 +775,7 @@ appendlet(dp, fp, verboselog, hsize, msize, convertmode)
 	     _CONVERT_UNKNOWN (3): Turn message to charset=UNKNOWN-8BIT, Q-P..
 	 */
 
-	register int i;
+	register int i, rc;
 	register int bufferfull;
 	int position = dp->msgbodyoffset;
 	int lastwasnl;
@@ -794,7 +792,9 @@ appendlet(dp, fp, verboselog, hsize, msize, convertmode)
 	/* can we use cache of message body data */
 	if (convertmode == _CONVERT_NONE &&
 	    readalready != 0) {
-	  if (writebuf(fp, let_buffer, readalready) != readalready) {
+	  rc = writebuf(fp, let_buffer, readalready);
+	  hsize += rc;
+	  if (rc != readalready) {
 	    if (gotalarm) {
 	      sprintf(remotemsg,"500 (let_buffer write timeout!  DATA %d/%d [%d%%])",
 		      hsize, msize, (hsize*100+msize/2)/msize);
@@ -828,7 +828,12 @@ appendlet(dp, fp, verboselog, hsize, msize, convertmode)
 	    }
 #endif /* !USE_MMAP */
 	    lastwasnl = (let_buffer[i-1] == '\n');
-	    if (writebuf(fp, let_buffer, i) != i) {
+	    rc = writebuf(fp, let_buffer, i);
+	    hsize += rc;
+	    if (statusreport)
+	      report("DATA %d/%d (%d%%)",
+		     hsize, msize, (hsize*100+msize/2)/msize);
+	    if (rc != i) {
 	      if (gotalarm) {
 		sprintf(remotemsg,"500 (let_buffer write timeout!  DATA %d/%d [%d%%])",
 			hsize, msize, (hsize*100+msize/2)/msize);
@@ -839,11 +844,6 @@ appendlet(dp, fp, verboselog, hsize, msize, convertmode)
 		      strerror(errno), hsize, msize, (hsize*100+msize/2)/msize);
 	      return EX_IOERR;
 	    }
-	    if (statusreport) {
-	      hsize += i;
-	      report("DATA %d/%d (%d%%)",
-		     hsize, msize, (hsize*100+msize/2)/msize);
-	    }
 #ifndef USE_MMAP
 	    bufferfull++;
 	    readalready = i;
@@ -893,7 +893,12 @@ appendlet(dp, fp, verboselog, hsize, msize, convertmode)
 	    /* XX: Detect multiparts !! */
 
 	    /* Ok, write the line -- decoding QP can alter the "lastwasnl" */
-	    if (writemimeline(fp, let_buffer, i, convertmode, &lastch) != i) {
+	    rc = writemimeline(fp, let_buffer, i, convertmode, &lastch);
+	    hsize += rc;
+	    if (statusreport)
+	      report("DATA %d/%d (%d%%)",
+		     hsize, msize, (hsize*100+msize/2)/msize);
+	    if (rc != i) {
 	      sprintf(remotemsg,
 		      "500 (let_buffer write IO-error! [%s] DATA %d/%d [%d%%])",
 		      strerror(errno), hsize, msize, (hsize*100+msize/2)/msize);
@@ -941,6 +946,12 @@ appendlet(dp, fp, verboselog, hsize, msize, convertmode)
 	return EX_OK;
 }
 
+
+#if 0
+# define VLFPRINTF(x) if(verboselog)fprintf x
+#else
+# define VLFPRINTF(x)
+#endif
 /*
  * Writebuf() is like write(), except all '\n' are converted to "\r\n"
  * (CRLF), and the sequence "\n." is converted to "\r\n..".
@@ -974,14 +985,14 @@ writebuf(fp, buf, len)
 		strcpy(remotemsg, "write error 1");
 		return EOF;
 	      }
-	      /* if (verboselog) fprintf(verboselog,".."); */
+	      VLFPRINTF((verboselog,".."));
 	    } else {
 	      if (putc(c, fp) == EOF) {
 		notaryreport(NULL,NULL,"500 (body write error, 2)");
 		strcpy(remotemsg, "write error 2");
 		return EOF;
 	      }
-	      /* if (verboselog) putc(c, verboselog); */
+	      VLFPRINTF((verboselog,"%c",c));
 	    }
 	  } else if (c == '\n') {
 	    if (putc('\r', fp) == EOF || putc(c, fp) == EOF) {
@@ -989,7 +1000,7 @@ writebuf(fp, buf, len)
 	      strcpy(remotemsg, "write error 3");
 	      return EOF;
 	    }
-	    /* if (verboselog) putc(c, verboselog); */
+	    VLFPRINTF((verboselog,"\r\n"));
 	    state = 1;
 	  } else {
 	    if (putc(c, fp) == EOF) {
@@ -997,7 +1008,7 @@ writebuf(fp, buf, len)
 	      strcpy(remotemsg, "write error 4");
 	      return EOF;
 	    }
-	    /* if (verboselog) putc(c, verboselog); */
+	    VLFPRINTF((verboselog,"%c",c));
 	  }
 	}
 	save = state;
@@ -1028,7 +1039,7 @@ writemimeline(fp, buf, len, convertmode, lastcharp)
 	 */
 
 	if (buf == NULL) {
-	  column = -1;
+	  column = -1; 
 	  return 0;
 	}
 
@@ -1081,8 +1092,8 @@ writemimeline(fp, buf, len, convertmode, lastcharp)
 	      putc('\r',fp);
 	      putc('\n',fp);
 	      *lastcharp = '\n';
-	      /* if (verboselog) fprintf(verboselog,"=\n"); */
-	      column = -1;
+	      VLFPRINTF((verboselog,"=\r\n"));
+	      column = 0;
 	    }
 	    /* Trailing SPACE/TAB ? */
 	    if (n < 3 && (c == ' ' || c == '\t')) {
@@ -1091,7 +1102,7 @@ writemimeline(fp, buf, len, convertmode, lastcharp)
 	      putc(i2h[(c)      & 15],fp);
 	      *lastcharp = i2h[(c) & 15];
 	      column += 2;
-	      /* if (verboselog) fprintf(verboselog,"=%02X",c); */
+	      VLFPRINTF((verboselog,"=%02X",c));
 	      continue;
 	    }
 	    /* Any other char which needs quoting ? */
@@ -1103,7 +1114,7 @@ writemimeline(fp, buf, len, convertmode, lastcharp)
 	      putc(i2h[(c)      & 15],fp);
 	      *lastcharp = i2h[(c) & 15];
 	      column += 2;
-	      /* if (verboselog) fprintf(verboselog,"=%02X",c); */
+	      VLFPRINTF((verboselog,"=%02X",c));
 	      continue;
 	    }
 	  } /* .... end convertmode	*/
@@ -1114,7 +1125,7 @@ writemimeline(fp, buf, len, convertmode, lastcharp)
 	      strcpy(remotemsg, "write error 1");
 	      return EOF;
 	    }
-	    /* if (verboselog) fprintf(verboselog,".."); */
+	    VLFPRINTF((verboselog,".."));
 	  }
 
 	  if (c == '\n') {
@@ -1123,7 +1134,7 @@ writemimeline(fp, buf, len, convertmode, lastcharp)
 	      strcpy(remotemsg, "write error 3");
 	      return EOF;
 	    }
-	    /* if (verboselog) putc(c, verboselog); */
+	    VLFPRINTF((verboselog,"\r"));
 	    column = -1;
 	  }
 	  if (putc(c, fp) == EOF) {
@@ -1132,7 +1143,7 @@ writemimeline(fp, buf, len, convertmode, lastcharp)
 	    return EOF;
 	  }
 	  *lastcharp = c;
-	  /* if (verboselog) putc(c, verboselog); */
+	  VLFPRINTF((verboselog,"%c",c));
 
 	}
 	return len;
@@ -2466,8 +2477,10 @@ struct ctldesc *dp;
 	/* With MMAP()ed spool file it is sweet and simple.. */
 	register char *s = dp->let_buffer + dp->msgbodyoffset;
 	while (s < dp->let_end)
-	  if (128 & *s) return 0;
-	  else ++s;
+	  if (128 & *s)
+	    return 0;
+	  else
+	    ++s;
 	return 1;
 #else /* !USE_MMAP */
 
